#! /bin/sh 
#-----------------------------------------------------------------
#Shell script to add local information to configuration file
#-----------------------------------------------------------------
BASE=$1
. `dirname $0`/../shell/version.sh
#-----------------------------------------------------
#loading the variable value
. $BASE/etc/$APPNAME/$APPNAME.conf
#-----------------------------------------------------
#Updating clement httpd configuration file
export hostipv4=`dig \`uname -n\` A +noall +short | head -1`;
export hostipv6=`dig \`uname -n\` AAAA +noall +short | head -1`;
if [ -z "$domain" ] ; then
  export domain=`dnsdomainname`
  fi

#to make sure we have at least an hostipv4 reference
if [ -z "$hostipv4" -a -z "$hostipv6" ] ; then
  export hostipv4=`grep \`uname -n\` /etc/hosts | cut  -f1`
  fi
export hostname=`uname -n | cut -d '.' -f1`
#-----------------------------------------------------------------
add_web()

{
#converting '.' to '\.'
reldom=`echo $domain | sed -e "s/\\./\\\\\\./g"`

cat >> $BASE/etc/httpd/conf.d/$APPNAME.conf <<!EOT
#$APPNAME START
#Done by the $APPNAME first start
#-----------------------------------------------------------------
#Listening on TLS port
Listen	443
#-----------------------------------------------------------------

<VirtualHost *:80>
	ServerName		$hostname.$domain
	ServerAlias		clement.$domain
        ServerAdmin		root@$domain
	RewriteEngine		on
	#comment it in if you want to debug redirect
	#LogLevel                alert rewrite:trace3
        RewriteCond		%{HTTP_HOST} ^clement\.$reldom		[OR]
        RewriteCond		%{HTTP_HOST} ^$hostname\.$reldom
        RewriteRule		^(.*)$ https://$hostname.$domain	[R=301]
        ErrorLog		logs/clemerr.log
        TransferLog		logs/clemlog.log
</VirtualHost>

<VirtualHost *:80>
        ServerName		web.clement.$domain
	serverAlias		www.$domain
        ServerAdmin		root@$domain
	RewriteEngine		on
	#comment it in if you want to debug redirect
	#LogLevel                alert rewrite:trace3
        RewriteCond		%{HTTP_HOST} ^www\.clement\.$reldom	[OR]
        RewriteCond		%{HTTP_HOST} ^web\.clement\.$reldom
        RewriteRule		^(.*)$ https://web-clement.$domain	[R=301]
        ErrorLog		logs/wwwmerr.log
        TransferLog		logs/wwwlog.log
</VirtualHost>

<IfDefine needwebmail>
<VirtualHost *:80>
        ServerALias		webmail.$domain
        ServerName		webmail-prod.$domain
        ServerAdmin		root@$domain
	RewriteEngine		on
	#comment it in if you want to debug redirect
	#LogLevel                alert rewrite:trace3
        RewriteCond		%{HTTP_HOST} ^webmail\.$reldom		[OR]
        RewriteCond		%{HTTP_HOST} ^webmail-prod\.$reldom
        RewriteRule		^(.*)$ https://webmail-prod.$domain	[R=301]
        ErrorLog		logs/webmerr.log
        TransferLog		logs/weblog.log
</VirtualHost>
</IfDefine>

<VirtualHost *:443>
        ServerName		$hostname.$domain
        ServerAlias		localhost.localdomain
        ServerAlias		clement.$domain
        ServerAdmin		root@$domain
        DocumentRoot		$BASE/var/www/$APPNAME
	setenv PATH_INFO	$BASE/etc/$APPNAME/$APPNAME.php
        Alias /base-dir/	$BASE/var/www/$APPNAME/ 
        Alias /reg-icons/	$BASE/var/www/$APPNAME/reg-icons/
        Alias /base-graph/	$BASE/var/www/$APPNAME/graph/
	ScriptAlias /cgi-bin/	$BASE/var/www/$APPNAME/
        <Directory		$BASE/var/www/$APPNAME>
                Options MultiViews FollowSymlinks ExecCGI
                AllowOverride AuthConfig FileInfo Indexes Limit Options
		Require all granted
        </Directory>
	<IfModule dir_module>
                DirectoryIndex index.php
        </IfModule>
	#----------------------------------------------
	#SSL
	SSLEngine On
	SSLCertificateKeyFile	$BASE/etc/pki/$APPNAME/clement-key.pem
	SSLCertificateFile	$BASE/etc/pki/$APPNAME/clement-cert.pem
	SSLProtocol		+TLSv1.3 +TLSv1.2
	SSLCompression		OFF
	SSLHonorCipherOrder	ON
	#----------------------------------------------
        ErrorLog logs/clemerr-ssl.log
        TransferLog logs/clemlog-ssl.log
</VirtualHost>

<VirtualHost *:443>
        ServerName		web.clement.$domain
	serverAlias		www.$domain
        ServerAdmin		root@$domain
	DirectoryIndex		menclem.php
	DocumentRoot		$BASE/var/www/$APPNAME/web
	<Directory		$BASE/var/www/$APPNAME/web>
		Options MultiViews FollowSymlinks
		AllowOverride AuthConfig FileInfo Indexes Limit Options
		Order allow,deny
		Allow from all
	</Directory>
	#----------------------------------------------
	#SSL
	SSLEngine On
	SSLCertificateKeyFile	$BASE/etc/pki/$APPNAME/clement-key.pem
	SSLCertificateFile	$BASE/etc/pki/$APPNAME/clement-cert.pem
	SSLProtocol		+TLSv1.3 +TLSv1.2
	SSLCompression		OFF
	SSLHonorCipherOrder	ON
	#----------------------------------------------
        ErrorLog		logs/wwwmerr-ssl.log
        TransferLog		logs/wwwlog-ssl.log
</VirtualHost>

<IfDefine needwebmail>
<VirtualHost *:443>
        ServerName		webmail.$domain
        ServerAdmin		root@$domain
	DirectoryIndex		index.php
	DocumentRoot		$BASE/usr/share/squirrelmail
	<Directory		$BASE/usr/share/squirrelmail>
		Options MultiViews FollowSymlinks
		AllowOverride AuthConfig FileInfo Indexes Limit Options
		Order allow,deny
		Allow from all
	</Directory>
	#----------------------------------------------
	#SSL
	SSLEngine On
	SSLCertificateKeyFile	$BASE/etc/pki/$APPNAME/clement-key.pem
	SSLCertificateFile	$BASE/etc/pki/$APPNAME/clement-cert.pem
	SSLProtocol		+TLSv1.3 +TLSv1.2
	SSLCompression		OFF
	SSLHonorCipherOrder	ON
	#----------------------------------------------
        ErrorLog		logs/webmerr-ssl.log
        TransferLog		logs/weblog-ssl.log
</VirtualHost>
</IfDefine>

#$APPNAME STOP
!EOT
}

#-----------------------------------------------------------------
#to setup the WEB interface
if [ -n "$hostipv4" -o -n "$hostipv6" ] ; then
  add_web
  fi

#-----------------------------------------------------------------
#updating dovecot sql access according data-base type
if [ -n "$LDAP_SERVER" ] ; then
  ln -nsf $BASE/etc/$APPNAME/dovecot-1.2-auth-ldap.conf	\
	  $BASE/etc/$APPNAME/dovecot-auth.conf
  if [ ! -f /etc/dovecot.conf ] ; then
    ln -nsf $BASE/etc/$APPNAME/dovecot-2.0-auth-ldap.conf	\
	    $BASE/etc/$APPNAME/dovecot-auth.conf
    fi
  (
  if [ -z "$LDAP_PROTO" -o -z "$LDAP_PORT" ] ; then
    LDAP_PROTO="LDAP";
    LDAP_PORT="389";
    fi
  echo "#Added by addconfig.sh for LDAP authentication" 
  echo "uris= $LDAP_PROTO://$LDAP_SERVER:$LDAP_PORT"
  echo "base= $LDAP_BASE"
  echo ""
  echo "auth_bind = yes"
  echo "pass_filter = (&(objectClass=qmailUser)(accountStatus=active)(|(uid=%u)($LDAP_EMAIL=%u)($LDAP_ALTERNATE_EMAIL=%u)))"
  echo "pass_attrs = uid=user"
  echo ""
  echo "user_filter = (&(objectclass=qmailUser)(accountStatus=active)(|(uid=%u)($LDAP_EMAIL=%u)($LDAP_ALTERNATE_EMAIL=%u)))"
  echo "user_attrs = mail=user,mailMessageStore=home=$BASE/var/spool/$APPNAME/mails/%$,=mail=maildir:~/dovecot"
  ) >> $BASE/etc/$APPNAME/dovecot-ldap.conf
  (
  echo "UPDATE clmgroup SET "
  echo "authserver='$LDAP_SERVER',authport=$LDAP_PORT,authproto='$LDAP_PROTO',"
  echo "ldapacc='uid=%s,$LDAP_BASE',ldaprootdn='$LDAP_ROODN'"
  case "$DB_TYPE" in 
    "POSTGRESQL"	)
       echo ",ldaprootp=encrypt('$LDAP_PASSWORD','$CODE_CRYPT','aes') "
       ;;
    "MYSQLI"		|		\
    "MYSQL"		)
       echo ",ldaprootp=encrypt('$LDAP_PASSWORD','$CODE_CRYPT') "
       ;;
    esac
  echo "WHERE groupid=1;"
  ) >> $BASE/etc/$APPNAME/base.sql
else
  (
  echo "#Added by addconfig.sh for $DB_TYPE data-base type" 
  echo "#"`date`
  case "$DB_TYPE" in 
    "POSTGRESQL"	)
      echo "driver = pgsql"
      echo "connect=  dbname=$APPNAME"
      echo "password_query=SELECT password,'Y' AS nopassword FROM users WHERE username='%u'"
      echo "user_query=SELECT 'clement' AS uid,'mail' AS gid,'/var/spool/clement/mails/%d/%n' AS home,'maildir:~/dovecot' AS mail,'*:storage='||mxmgbytes||'M' AS quota_rule FROM userprofile WHERE prfid=(SELECT prfid FROM users WHERE username='%u')"
      ;;
    "MYSQLI"		|		\
    "MYSQL"		)
      echo "driver = mysql"
      echo "connect= host=localhost dbname=$APPNAME"
      echo "password_query=SELECT password,'Y' AS nopassword FROM users WHERE username='%u'"
      echo "user_query=SELECT 'clement' AS uid,'mail' AS gid,'/var/spool/clement/mails/try1.safe.ca/root' AS home,'maildir:~/dovecot' AS mail,concat('*:storage=',mxmgbytes,'M') AS quota_rule from userprofile WHERE prfid=(SELECT prfid FROM users WHERE username='%u')"
      ;;
    esac
  ) >> $BASE/etc/$APPNAME/dovecot-sql.conf
  ln -nsf $BASE/etc/$APPNAME/dovecot-dict-$DB_TYPE.conf.ext $BASE/etc/$APPNAME/dovecot-dict-sql.conf.ext
  ln -nsf $BASE/etc/$APPNAME/dovecot-1.2-auth-sql.conf	\
	  $BASE/etc/$APPNAME/dovecot-auth.conf
  if [ ! -f /etc/dovecot.conf ] ; then
    ln -nsf $BASE/etc/$APPNAME/dovecot-2.0-auth-sql.conf	\
	    $BASE/etc/$APPNAME/dovecot-auth.conf
    fi
  case "$DB_TYPE" in 
    "POSTGRESQL"	)
      sed -i -e "s/sqlquota=dbsql/sqlquota=pgsql/" $BASE/etc/$APPNAME/dovecot-2.0.conf
      ;;
    "MYSQLI"		|		\
    "MYSQL"		)
      sed -i -e "s/sqlquota=dbsql/sqlquota=mysql/" $BASE/etc/$APPNAME/dovecot-2.0.conf
      ;;
    esac
  fi
#-----------------------------------------------------------------
#adjusting http included module
sed -i								\
  -e "s/^#LoadModule ssl_module/LoadModule ssl_module/" 	\
  -e "s/^#LoadModule rewrite_module/LoadModule rewrite_module/"	\
  -e "s/^#LoadModule socache_shmcb_/LoadModule socache_shmcb_/"	\
  /etc/httpd/httpd.conf
#-----------------------------------------------------------------
#Setting a random string for LDAP ROOT password crypting
sed -i 								\
  -e"s:^CODE_CRYPT=\"your_password\":CODE_CRYPT=\"`/usr/bin/mkpasswd -s 0 -5`\":" \
  $BASE/etc/$APPNAME/$APPNAME.conf
#-----------------------------------------------------------------

